coherence.upnp.services.clients.connection_manager_client (module) — Cohen3 0.8.0 documentation

# coherence.upnp.services.clients.connection_manager_client (module)

class `ConnectionManagerClient`(service)

  Bases: `object`

  `connection_manager_id`()
  `remove`()
  `subscribe_for_variable`(var_name, callback, signal=False)
  `get_protocol_info`()
  `prepare_for_connection`(remote_protocol_info, peer_connection_manager, peer_connection_id, direction)
  `connection_complete`(connection_id)
  `get_current_connection_ids`()
  `get_current_connection_info`(connection_id)